/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * 
 * Contact Information:
 * Dambach-Werke GmbH
 * Elektronische Leitsysteme
 * Fritz-Minhardt-Str. 1
 * 76456 Kuppenheim
 * Phone: +49-7222-402-0
 * Fax: +49-7222-402-200
 * mailto: info@els.dambach.de
 */

package de.bsvrz.vew.sim.sim.steuerung;

import de.bsvrz.vew.sim.sim.simulation.Simulation;

/**
 * Steuerung zu einer Simulation.
 * Diese abstrake Oberklasse kapselt diejenigen Funktionalitäten, die unabhängig
 * etwa von den Online -oder Offline Eigenschaften einer Simulation sind
 * *  
 * @version  $Revision: 1.1 $ / $Date: 2008/10/31 13:30:30 $ / ($Author: Sans $)
 * @author  Dambach-Werke GmbH
 * @author  Stefan Sans
 */
public abstract class SteuerungSimulationAbstrakt implements SteuerungSimulation
{
  // private final static Debug _debug = Debug.getLogger();
  
  /**
   * Die Simulation, der diese Steuerung zugeordnet ist
   */
  protected final Simulation _simulation;
  
  /*
  protected boolean _startStopGestartet;
  protected boolean _startStopGestoppt;
  protected boolean _startStopBeendet;
  */
        
  /**
   * Erzeuge eine neue Steuerung zu einer Simulation
   * @param simulation die Simulation, zu der die Instanz erzeugt werden soll
   */
  public SteuerungSimulationAbstrakt(Simulation simulation)
  {
    _simulation = simulation;
  }
  
  
  public abstract boolean erstelleWorkflow(int uebergang);
  
  public abstract boolean sendeZustand();

  /*
  public boolean isStartStopGestartet()
  {
    return _startStopGestartet;
  }

  public boolean isStartStopGestoppt()
  {
    return _startStopGestoppt;
  }
  
  public boolean isStartStopBeendet()
  {
    return _startStopBeendet;
  }
  */
  
  public boolean sendeStart()
  {
    boolean result = new StartStopStart(_simulation).sendeStart();
    /*
    if (result)
    {
      _startStopGestartet = true;
      _startStopGestoppt = false;
      _startStopBeendet = false;
    }
    else
    {
      _startStopGestartet = false;
    }
    */
    return result;
  } 
  
  public boolean sendeStop()
  {
    boolean result = new StartStopStop(_simulation).sendeStop();
    /*
    if (result)
    {
      _startStopGestartet = false;
      _startStopGestoppt = true;
      _startStopBeendet = false;
    }
    else
    {
      _startStopGestoppt = false;
    }
    */
    return result;
  }
    
  public boolean sendeBeenden()
  {
    boolean result = new StartStopBeenden(_simulation).sendeBeenden();
    /*
    if (result)
    {
      _startStopGestartet = false;
      _startStopGestoppt = false;
      _startStopBeendet = true;
    }
    else
    {
      _startStopBeendet = false;
    }
    */
    return result;
  }
}
